# Contributing
We would love your help with anything!<br>
If you find a bug raise an issue, and if you have a suggestion go ahead and fork it - but be sure to open an issue first. That helps with management and organization.

I also use [ZenHub](https://www.zenhub.com/), an project management platform hat integrates with GitHub. If you use it you can see the boards we organize with. If you don't, you simply won't see anything!

***

## Rules
* **Make changes on the `rivermont:master` branch but make a PR against `rivermont:dev`.**
* If you make changed to `crawler.py`, please adjust the line values in `docs.md`. That way links won't break.
* If you make any changes please update the version as well as the badges on README lines [20 and 21](https://github.com/rivermont/spidy/blob/master/README.md#L20).

* `Lines of Code` is calculated: `len(crawler.py) + len(gui.py) + len(tests.py)`
* `Lines of Docs` is calculated: `len(README.md) + len(DOCS.md) + len(CONTRIBUTE.md)`


## Guidelines

Very trivial edits may be ignored, but things like spelling and grammar correction is fine.

Thanks!

***
